@@ -33,14 +33,14 @@ pub(crate) struct BytesParam {
 /// instanciated adopt immediately the change. Config wrapped in Mutex
 /// makes the implementation threadsafe.
 pub struct BytesConfig {
-    pub(crate) config: Arc<Mutex<Cell<BytesParam>>>,
+    pub(crate) config: Arc<Mutex<RefCell<BytesParam>>>,
 }
 
 impl BytesConfig {
     /// Specify preferences for the creation of the `BytesConfig` struct.
     pub fn new(base: BytesBase, precision: usize, padded: bool) -> Self {
         Self {
-            config: Arc::new(Mutex::new(Cell::new(BytesParam {
+            config: Arc::new(Mutex::new(RefCell::new(BytesParam {
                 base,
                 precision,
                 aligned: padded,
@@ -49,25 +49,22 @@ impl BytesConfig {
     }
 
     /// Specify the base used for the display of bytes: Gabyte = 1000 bytes or bibyte = 1024 bytes
-    pub fn set_base(&mut self, b: BytesBase) {
+    pub fn set_base(&self, b: BytesBase) {
         // Acquire lock on config and modify cell content
-        let mut config = (*self.config).lock().unwrap().get();
-        config.base = b;
-        (*self.config).lock().unwrap().set(config);
+        let config = (*self.config).lock().unwrap();
+        config.borrow_mut().base = b;
     }
 
     /// Specify whether the display of values is aligned or not
-    pub fn set_aligned(&mut self, pa: bool) {
-        let mut config = (*self.config).lock().unwrap().get();
-        config.aligned = pa;
-        (*self.config).lock().unwrap().set(config);
+    pub fn set_aligned(&self, pa: bool) {
+        let config = (*self.config).lock().unwrap();
+        config.borrow_mut().aligned = pa;
     }
 
     /// Specify how many decimals to display
-    pub fn set_precision(&mut self, pr: usize) {
-        let mut config = (*self.config).lock().unwrap().get();
-        config.precision = pr;
-        (*self.config).lock().unwrap().set(config);
+    pub fn set_precision(&self, pr: usize) {
+        let config = (*self.config).lock().unwrap();
+        config.borrow_mut().precision = pr;
     }
 
     /// Creates an instance of `Bytes` that stores a reference to the
@@ -82,7 +79,7 @@ impl Default for BytesConfig {
     /// and the display of values is not aligned
     fn default() -> Self {
         Self {
-            config: Arc::new(Mutex::new(Cell::new(BytesParam {
+            config: Arc::new(Mutex::new(RefCell::new(BytesParam {
                 base: BytesBase::default(),
                 precision: 2,
                 aligned: false,
