@@ -23,7 +23,7 @@
 //!
 //! See example for more details.
 
-use std::cell::Cell;
+use std::cell::RefCell;
 use std::fmt::{Display, Formatter, Result};
 use std::sync::{Arc, Mutex};
 
@@ -54,13 +54,13 @@ pub const BIBYTES: [&str; 7] = ["B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB"];
 /// to compare it.
 #[derive(Default, Clone)]
 pub struct Bytes<U: Unsigned + Display + PartialOrd + Into<u64> + Copy> {
-    config: Arc<Mutex<Cell<BytesParam>>>,
+    config: Arc<Mutex<RefCell<BytesParam>>>,
     bytes: U,
 }
 
 impl<U: Unsigned + Display + PartialOrd + Into<u64> + Copy> Bytes<U> {
     /// Used by BytesConfig struct to instanciate Byte
-    fn new(config: Arc<Mutex<Cell<BytesParam>>>, byte: U) -> Self {
+    fn new(config: Arc<Mutex<RefCell<BytesParam>>>, byte: U) -> Self {
         Self {
             config,
             bytes: byte,
@@ -88,17 +88,17 @@ where
 {
     fn fmt(&self, f: &mut Formatter) -> Result {
         // Obtain base from associated BytesBuilder
-        let base: u64 = match (*self.config).lock().unwrap().get().base {
+        let base: u64 = match (*self.config).lock().unwrap().borrow().base {
             BytesBase::Gabyte => 1000,
             BytesBase::Bibyte => 1024,
         };
 
         // Obtain number of decimals to display from associated BytesBuilder
-        let precision: usize = (*self.config).lock().unwrap().get().precision;
+        let precision: usize = (*self.config).lock().unwrap().borrow().precision;
         let prec_factor: f64 = 10.0_f64.powi(precision as i32);
 
         // Obtain padding from associated BytesBuilder
-        let aligned: bool = (*self.config).lock().unwrap().get().aligned;
+        let aligned: bool = (*self.config).lock().unwrap().borrow().aligned;
 
         // Convert value into known type (u64 is the only one that can fit all others)
         // because we can't do comparisons with generic types.
